#!/bin/bash

COMPOSE_CFG=
APPPREFIX=example
source ~/.bash_profile
while getopts "f:p:r:" optchar; do
    case "${optchar}" in
        f) COMPOSE_CFG=" -f ${OPTARG}" ;;
        p) APPPREFIX=${OPTARG} ;;
        r) REGION=${OPTARG} ;;
    esac
done
shift $(expr $OPTIND - 1 )
TRITON=${REGION:-sw}
source setuptriton.sh triton $TRITON
echo -e $(env |grep -E '(MANT|DNS|SDC)')

COMPOSE_CFG=

declare -a rArray=$(  yaml2json  docker-compose.yml |jq ".nginx.links" |awk -F: '/:/{out=out$1"\" ";ct++}END{print("("out"\"nginx\")")}'|sed 's/,)/\)/')

echo $rArray
function getService(){
theString=$1
cat << EOF
{{range services }}\n
    {{if eq .Name "$theString"}}\n

		server {\n
				server_name {{plugin "node" "/application/index.js" "--task" "serverAlias" "--service" .Name}};\n
				listen 80 ;\n
				location / {\n
				   proxy_redirect off;\n
						  proxy_http_version 1.1;\n
						proxy_set_header Upgrade \$http_upgrade;\n
						proxy_set_header Connection "upgrade";\n
						proxy_set_header Host \$host;\n
						proxy_set_header X-Forwarded-Host \$host;\n
						proxy_set_header X-Forwarded-Server \$host;\n
						proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;\n
						proxy_set_header X-Real-IP \$remote_addr;\n
						proxy_pass http://{{.Name}}/;\n
				}\n
				location = "" {\n
					   return 302 /;\n
				 }\n

		}\n

	{{end}}\n
{{end}}\n
EOF

}

function getString(){
theString=$1
cat << EOF
{{range services}}\n
	{{if eq .Name "$theString"}}\n
		upstream $theString {\n
		{{range service .Name}}\n
			server {{.Address}}:{{.Port}};\n
		{{end}}\n
		}\n
	{{end}}\n
{{end}}\n
EOF
}
function loopArray {
for i in "${rArray[@]}"
  do
   echo  $(getString $i)
  done
cat <<EOF
 server {\n
    listen       80;\n
    server_name  _;\n
    location /health.txt {\n
        add_header content-type "text/html";\n
        alias /usr/share/nginx/html/index.html;\n
    }\n
    {{range services}}\n
    location /{{.Name}}/ {\n
        proxy_pass http://{{.Name}}/;\n
        proxy_redirect off;\n
        proxy_http_version 1.1;\n
		proxy_set_header Upgrade \$http_upgrade;\n
		proxy_set_header Connection "upgrade";\n
		proxy_set_header Host \$host;\n
		proxy_set_header X-Forwarded-Host \$host;\n
		proxy_set_header X-Forwarded-Server \$host;\n
		proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;\n
		proxy_set_header X-Real-IP \$remote_addr;\n
    }\n
      location = /{{.Name}} {\n
            return 302 /{{.Name}}/;\n
        }\n
    {{end}}\n
}\n
EOF
for i in "${rArray[@]}"
  do
   echo  $(getService $i)
  done
 }
replaceString=$(loopArray)

echo -e $replaceString >nginx/default.ctmpl











COMPOSE="docker-compose -p ${APPPREFIX}${COMPOSE_CFG:-}"
CONFIG_FILE=${COMPOSE_CFG:-docker-compose.yml}

echo "project prefix:      $APPPREFIX"
echo "docker-compose file: $CONFIG_FILE"
echo "region: $REGION"

echo 'Pulling latest container versions'
${COMPOSE} pull consul
${COMPOSE} pull nginx

echo 'Starting Consul.'
${COMPOSE} up -d consul

# get network info from consul and poll it for liveness
if [ -z "${COMPOSE_CFG}" ]; then
    CONSUL_IP=$(sdc-listmachines --name ${APPPREFIX}_consul_1 | json -a ips.1)
else
    CONSUL_IP=${CONSUL_IP:-$(docker-machine ip default)}
fi


echo "Writing template values to Consul at ${CONSUL_IP}"
while :
do
    # we'll sometimes get an HTTP500 here if consul hasn't completed
    # it's leader election on boot yet, so poll till we get a good response.
    sleep 1
    curl --fail  -X PUT --data-binary @./nginx/default.ctmpl \
         http://${CONSUL_IP}:8500/v1/kv/nginx/template && break
    echo -ne .
done

echo
echo 'Copying consul ip'
#open http://${CONSUL_IP}:8500/ui
echo "${CONSUL_IP}" > /tmp/consulip

echo 'Starting Nginx'
${COMPOSE} up -d --no-deps nginx

